@@ -16,11 +16,12 @@ if (got_texmex) {
   class(temp) <- "texmex_evmOpt"
 
   test_that("texmex::evm, GEV: logLik() vs. logLik(logLikVec)", {
-    testthat::expect_equivalent(logLik(mod), logLik(logLikVec(temp)))
+    testthat::expect_equal(logLik(mod), logLik(logLikVec(temp)),
+                           ignore_attr = TRUE)
   })
   # Check that alogLik also returned the correct maximised log-likelihood
   test_that("texmex::evm, GEV: logLik() vs. logLik(logLikVec)", {
-    testthat::expect_equivalent(logLik(mod), logLik(adj_mod))
+    testthat::expect_equal(logLik(mod), logLik(adj_mod), ignore_attr = TRUE)
   })
   # Check logLik.texmex_evmOpt, GEV: trivially correct
   test_that("texmex::evm, GEV: logLik() vs. logLik(logLikVec)", {
@@ -34,11 +35,12 @@ if (got_texmex) {
   class(temp) <- "texmex_evmOpt"
 
   test_that("texmex::evm, EGP3: logLik() vs. logLik(logLikVec)", {
-    testthat::expect_equivalent(logLik(mod), logLik(logLikVec(temp)))
+    testthat::expect_equal(logLik(mod), logLik(logLikVec(temp)),
+                           ignore_attr = TRUE)
   })
   # Check that alogLik also returned the correct maximised log-likelihood
   test_that("texmex::evm, EGP3: logLik() vs. logLik(logLikVec)", {
-    testthat::expect_equivalent(logLik(mod), logLik(adj_mod))
+    testthat::expect_equal(logLik(mod), logLik(adj_mod), ignore_attr = TRUE)
   })
   # Check logLik.texmex_evmOpt, EGP3: trivially correct
   test_that("texmex::evm, EGP3: logLik() vs. logLik(logLikVec)", {
@@ -52,11 +54,12 @@ if (got_texmex) {
   class(temp) <- "texmex_evmOpt"
 
   test_that("texmex::evm, EGP3: logLik() vs. logLik(logLikVec)", {
-    testthat::expect_equivalent(logLik(mod), logLik(logLikVec(temp)))
+    testthat::expect_equal(logLik(mod), logLik(logLikVec(temp)),
+                           ignore_attr = TRUE)
   })
   # Check that alogLik also returned the correct maximised log-likelihood
   test_that("texmex::evm, EGP3: logLik() vs. logLik(logLikVec)", {
-    testthat::expect_equivalent(logLik(mod), logLik(adj_mod))
+    testthat::expect_equal(logLik(mod), logLik(adj_mod), ignore_attr = TRUE)
   })
   # Check logLik.texmex_evmOpt, EGP3: trivially correct
   test_that("texmex::evm, EGP3: logLik() vs. logLik(logLikVec)", {
@@ -78,11 +81,12 @@ if (got_texmex) {
     class(temp) <- "texmex_evmOpt"
 
     test_that("texmex::evm, GEV, reg: logLik() vs. logLik(logLikVec)", {
-      testthat::expect_equivalent(logLik(mod), logLik(logLikVec(temp)))
+      testthat::expect_equal(logLik(mod), logLik(logLikVec(temp)),
+                             ignore_attr = TRUE)
     })
     # Check that alogLik also returned the correct maximised log-likelihood
     test_that("texmex::evm, GEV, reg: logLik() vs. logLik(logLikVec)", {
-      testthat::expect_equivalent(logLik(mod), logLik(adj_mod))
+      testthat::expect_equal(logLik(mod), logLik(adj_mod), ignore_attr = TRUE)
     })
     # Check logLik.texmex_evmOpt, EGP3: trivially correct
     test_that("texmex::evm, GEV, reg: logLik() vs. logLik(logLikVec)", {
@@ -101,11 +105,12 @@ if (got_texmex) {
   class(temp) <- "texmex_evmOpt"
 
   test_that("texmex::evm, GP, reg: logLik() vs. logLik(logLikVec)", {
-    testthat::expect_equivalent(logLik(mod), logLik(logLikVec(temp)))
+    testthat::expect_equal(logLik(mod), logLik(logLikVec(temp)),
+                           ignore_attr = TRUE)
   })
   # Check that alogLik also returned the correct maximised log-likelihood
   test_that("texmex::evm, GP, reg: logLik() vs. logLik(logLikVec)", {
-    testthat::expect_equivalent(logLik(mod), logLik(adj_mod))
+    testthat::expect_equal(logLik(mod), logLik(adj_mod), ignore_attr = TRUE)
   })
   # Check logLik.texmex_evmOpt, EGP3: trivially correct
   test_that("texmex::evm, GP, reg: logLik() vs. logLik(logLikVec)", {
